@@ -47,6 +47,7 @@ import org.kie.workbench.common.widgets.metadata.client.KieDocument;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.client.callbacks.Callback;
 import org.uberfire.ext.widgets.common.client.common.HasBusyIndicator;
+import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.GridSelectionManager;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.GridPinnedModeManager;
@@ -185,5 +186,9 @@ public interface GuidedDecisionTableView extends GridWidget,
         void link(final Set<GuidedDecisionTableView.Presenter> dtPresenters);
 
         boolean hasEditableColumns();
+
+        void setShowRuleName(final boolean show);
+
+        void onSort(final GridColumn gridColumn) ;
     }
 }
