@@ -97,6 +97,7 @@ import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLienzoPane
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
+import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.promise.SyncPromises;
 import org.uberfire.workbench.events.NotificationEvent;
@@ -104,6 +105,7 @@ import org.uberfire.workbench.model.menu.MenuItem;
 
 import static org.junit.Assert.fail;
 import static org.kie.workbench.common.services.shared.preferences.ApplicationPreferences.DATE_FORMAT;
+import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.eq;
@@ -343,6 +345,7 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
         when(modeller.getView()).thenReturn(modellerView);
         when(modellerView.getGridPanel()).thenReturn(modellerGridPanel);
         when(versionRecordManager.newSaveMenuItem(any(Command.class))).thenReturn(saveMenuItem);
+        when(versionRecordManager.newSaveMenuItem(any(ParameterizedCommand.class))).thenReturn(saveMenuItem);
         when(versionRecordManager.buildMenu()).thenReturn(versionManagerMenuItem);
         when(editMenuBuilder.build()).thenReturn(editMenuItem);
         when(viewMenuBuilder.build()).thenReturn(viewMenuItem);
@@ -384,9 +387,9 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
         when(modeller.addDecisionTable(eq(path),
                                        eq(placeRequest),
                                        eq(content),
-                                       any(Boolean.class),
-                                       any(Double.class),
-                                       any(Double.class))).thenReturn(dtPresenter);
+                                       anyBoolean(),
+                                       any(),
+                                       any())).thenReturn(dtPresenter);
         when(path.getOriginal()).thenReturn(originalPath);
         when(dtPresenter.getLatestPath()).thenReturn(path);
         when(dtPresenter.getCurrentPath()).thenReturn(path);
